@@ -20,7 +20,7 @@ pub fn boot() {
 
 #[macro_export]
 macro_rules! call_on_boot {
-  ($boot:block) => {
+  ($boot_fn:block) => {
     use $crate::{atomic_take::AtomicTake, inventory, BootBox};
 
     inventory::submit! {
@@ -30,3 +30,22 @@ macro_rules! call_on_boot {
     }
   };
 }
+
+#[cfg(test)]
+mod tests {
+  use super::*;
+
+  use std::sync::atomic::{AtomicBool, Ordering};
+
+  static BOOT_CALLED: AtomicBool = AtomicBool::new(false);
+
+  call_on_boot!({
+    BOOT_CALLED.store(true, Ordering::SeqCst);
+  });
+
+  #[test]
+  fn it_boots() {
+    boot();
+    assert!(BOOT_CALLED.load(Ordering::SeqCst));
+  }
+}
